/*
 * SimpleApp Demo
 * 
 * Copyright (c) 2010, CodeRight
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice and this list of conditions.
 *   - Redistributions in binary form must reproduce the above
 *     copyright notice and this list of conditions in the 
 *     documentation and/or other materials provided with the 
 *     distribution.
 * 
 * Jazz Desktop Application Framework
 * http://jazz.coderight.nl
 * 
 * Author: Will Boluyt
 */
package nl.coderight.jazz.demo.ext;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JSeparator;

import nl.coderight.jazz.ProgressMonitor;
import nl.coderight.jazz.event.ProgressEvent;
import nl.coderight.jazz.view.StatusBar;

public class XStatusBar extends StatusBar implements ProgressMonitor {
	private JProgressBar progressBar;
	private JLabel username;

	public XStatusBar() {
		setMessage("Jazz Desktop Application Framework Demo");
	}

	protected JComponent createComponent() {
		username = new JLabel(getResourceAsIcon("user.png"));
		username.setHorizontalAlignment(JLabel.LEFT);				
		
		progressBar = new JProgressBar();
		progressBar.setPreferredSize(new Dimension(150, 15));
		progressBar.setEnabled(false);
		
		JPanel progressPanel = new JPanel(new BorderLayout());
		progressPanel.add(progressBar, BorderLayout.CENTER);

		JLabel label = new JLabel(" DEMO ");
		label.setBackground(Color.ORANGE);
		label.setOpaque(true);
		
		JPanel panel = new JPanel();
		panel.setLayout(new FlowLayout(FlowLayout.RIGHT, 10, 0));
		panel.add(createSeparator());
		panel.add(label);
		panel.add(createSeparator());
		panel.add(progressBar);
		panel.add(createSeparator());
		panel.add(username);

		JComponent component = super.createComponent();
		component.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 5));
		
		JPanel bar = new JPanel(new BorderLayout());
		bar.add(new JSeparator(), BorderLayout.NORTH);
		bar.add(component, BorderLayout.WEST);
		bar.add(panel, BorderLayout.CENTER);
		return bar;
	}
	
	private JSeparator createSeparator() {
		JSeparator separator = new JSeparator(JSeparator.VERTICAL);
		separator.setPreferredSize(new Dimension(2, 20));
		return separator;
	}
	
	public void setUsername(String username) {
		this.username.setText(username);
	}

	public void startProgress(ProgressEvent evt) {
		progressBar.setStringPainted(true);
		progressBar.setString(evt.getMessage());
		progressBar.setMinimum(evt.getMinimum());
		progressBar.setMaximum(evt.getMaximum());
		progressBar.setIndeterminate(evt.isIndeterminate());
	}

	public void updateProgress(ProgressEvent evt) {
		progressBar.setValue(evt.getProgress());
	}	

	public void stopProgress(ProgressEvent evt) {
		progressBar.setStringPainted(false);
		progressBar.setIndeterminate(false);
		progressBar.setValue(progressBar.getMinimum());
	}

}
