/*
 * SimpleApp Demo
 * 
 * Copyright (c) 2010, CodeRight
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice and this list of conditions.
 *   - Redistributions in binary form must reproduce the above
 *     copyright notice and this list of conditions in the 
 *     documentation and/or other materials provided with the 
 *     distribution.
 * 
 * Jazz Desktop Application Framework
 * http://jazz.coderight.nl
 * 
 * Author: Will Boluyt
 */
package nl.coderight.jazz.demo.field;

import java.text.SimpleDateFormat;

import nl.coderight.jazz.demo.domain.Contact;
import nl.coderight.jazz.demo.validation.EmailValidator;

import nl.coderight.jazz.form.FormLayout;
import nl.coderight.jazz.form.FormLayout.Align;
import nl.coderight.jazz.form.FormLayout.Resize;
import nl.coderight.jazz.form.control.CalendarControl;
import nl.coderight.jazz.form.control.GroupControl;
import nl.coderight.jazz.form.field.TextField;

public class ContactField extends GroupControl<Contact> {	
	private TextField firstnameField; 
	private TextField lastnameField;
	private CalendarControl birthdayField;
	private TextField phoneField; 
	private TextField emailField;
	
	
	public ContactField(String bindID) {
		setTitle("header.contact");
		setBindID(bindID);
		createFields();
		createLayout();
	}
	
	private void createFields() {
		firstnameField = new TextField("firstname", 20);
		firstnameField.setRequired(true);
		
		lastnameField = new TextField("lastname", 20);
		lastnameField.setRequired(true);
		
		birthdayField = new CalendarControl("birthday", 20);
		birthdayField.setFormat(new SimpleDateFormat(translate("date.format")));
		birthdayField.showYearSpinner(true);
		
		phoneField = new TextField("phone", 20);	
		phoneField.setMask("(###) ###-####", true);
		phoneField.setEditable(false);
		
		emailField = new TextField("email", 30);		
		emailField.setValidator(new EmailValidator());
	}

	private void createLayout() {
		setLayout(new FormLayout())
				
			.addLabel("label.firstname").addField(firstnameField)
			.addLabel("label.lastname")	.addField(lastnameField)
			.addRow()
			.addLabel("label.birthday")	.addField(birthdayField, Resize.HORIZONTAL)
			.addRow()
			.addLabel("label.phone")	.addField(phoneField)
			.addRow()
			.addLabel("label.email")	.addField(emailField, Align.LEFT, Resize.HORIZONTAL, 3, 1);
		
	}
	
}
