/*
 * SimpleApp Demo
 * 
 * Copyright (c) 2010, CodeRight
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice and this list of conditions.
 *   - Redistributions in binary form must reproduce the above
 *     copyright notice and this list of conditions in the 
 *     documentation and/or other materials provided with the 
 *     distribution.
 * 
 * Jazz Desktop Application Framework
 * http://jazz.coderight.nl
 * 
 * Author: Will Boluyt
 */
package nl.coderight.jazz.demo.task;

import java.util.List;

import nl.coderight.jazz.Task;
import nl.coderight.jazz.demo.domain.Contact;
import nl.coderight.jazz.demo.event.ContactEvent;
import nl.coderight.jazz.demo.event.ContactEvent.ContactEventType;
import nl.coderight.jazz.demo.service.DatabaseService;
import nl.coderight.jazz.event.MessageEvent;
import nl.coderight.jazz.event.ProgressEvent;
import nl.coderight.jazz.event.MessageEvent.MessageEventType;
import nl.coderight.jazz.event.ProgressEvent.ProgressEventType;

public class LoadContactsTask extends Task<List<Contact>>{

	@Override
	public List<Contact> process() throws Exception {
		return DatabaseService.getInstance().getContacts();
	}

	@Override
	protected void onStart() {
		ProgressEvent progressEvent = new ProgressEvent(ProgressEventType.START);
		progressEvent.setMessage("Loading contacts...");
		progressEvent.setIndeterminate(true);
		postEvent(progressEvent);
	}
	
	@Override
	protected void onFinish() {
		postEvent(new ProgressEvent(ProgressEventType.STOP));
		
		ContactEvent contactEvent = new ContactEvent(ContactEventType.LOAD_SUCCESS);
		contactEvent.setContacts(getResult());
		postEvent(contactEvent);
	}
	
	@Override
	protected void onError() {
		MessageEvent error = new MessageEvent(MessageEventType.ERROR);
		error.setMessage(getError().getMessage());
		postEvent(error);			
	}
	
}
